@@ -85,7 +85,7 @@ void load_settings(GtkWidget* main, gchar* session, gchar *filename) {
 		// load configuration (preferences)
 		stmp = g_key_file_get_string(settings_file, CONFIG_GROUP, "command", NULL);
 		if (stmp != NULL) strncpy(config_command, stmp, MAXPATH - 1);
-		
+
 		btmp = g_key_file_get_boolean(settings_file, CONFIG_GROUP, "output", &error_handler);
 		if (error_handler != NULL) g_clear_error (&error_handler);
 		else config_output = btmp;
@@ -145,6 +145,7 @@ void load_settings(GtkWidget* main, gchar* session, gchar *filename) {
 
 	set_checkbox(main, "check_sum", g_key_file_get_boolean(settings_file, session, "check_sum", NULL));
 	set_checkbox(main, "check_symlink", g_key_file_get_boolean(settings_file, session, "check_symlink", NULL));
+	set_checkbox(main, "check_hardlink", g_key_file_get_boolean(settings_file, session, "check_hardlink", NULL));
 	set_checkbox(main, "check_dev", g_key_file_get_boolean(settings_file, session, "check_dev", NULL));
 	set_checkbox(main, "check_update", g_key_file_get_boolean(settings_file, session, "check_update", NULL));
 	set_checkbox(main, "check_keepart", g_key_file_get_boolean(settings_file, session, "check_keepart", NULL));
@@ -153,6 +154,7 @@ void load_settings(GtkWidget* main, gchar* session, gchar *filename) {
 	set_checkbox(main, "check_backup", g_key_file_get_boolean(settings_file, session, "check_backup", NULL));
 
 	set_checkbox(main, "check_com_before", g_key_file_get_boolean(settings_file, session, "check_com_before", NULL));
+	set_checkbox(main, "check_com_halt", g_key_file_get_boolean(settings_file, session, "check_com_halt", NULL));
 	set_checkbox(main, "check_com_after", g_key_file_get_boolean(settings_file, session, "check_com_after", NULL));
 	set_checkbox(main, "check_browse_files", g_key_file_get_boolean(settings_file, session, "check_browse_files", NULL));
 
@@ -175,7 +177,7 @@ void save_settings(GtkWidget* main, gchar *session, gchar *filename) {
 //	g_printf(_("Saving settings to %s...\n"), settings_file_name);
 	g_mkdir(grsync_dir, 0700);
 	settings_file = g_key_file_new();
-	
+
 	if (filename == NULL) {
 		g_key_file_load_from_file(settings_file, settings_file_name, G_KEY_FILE_NONE, NULL);
 
@@ -223,6 +225,7 @@ void save_settings(GtkWidget* main, gchar *session, gchar *filename) {
 
 	g_key_file_set_boolean(settings_file, session, "check_sum", get_checkbox(main, "check_sum"));
 	g_key_file_set_boolean(settings_file, session, "check_symlink", get_checkbox(main, "check_symlink"));
+	g_key_file_set_boolean(settings_file, session, "check_hardlink", get_checkbox(main, "check_hardlink"));
 	g_key_file_set_boolean(settings_file, session, "check_dev", get_checkbox(main, "check_dev"));
 	g_key_file_set_boolean(settings_file, session, "check_update", get_checkbox(main, "check_update"));
 	g_key_file_set_boolean(settings_file, session, "check_keepart", get_checkbox(main, "check_keepart"));
@@ -231,6 +234,7 @@ void save_settings(GtkWidget* main, gchar *session, gchar *filename) {
 	g_key_file_set_boolean(settings_file, session, "check_backup", get_checkbox(main, "check_backup"));
 
 	g_key_file_set_boolean(settings_file, session, "check_com_before", get_checkbox(main, "check_com_before"));
+	g_key_file_set_boolean(settings_file, session, "check_com_halt", get_checkbox(main, "check_com_halt"));
 	g_key_file_set_boolean(settings_file, session, "check_com_after", get_checkbox(main, "check_com_after"));
 	g_key_file_set_boolean(settings_file, session, "check_browse_files", get_checkbox(main, "check_browse_files"));
 
@@ -327,7 +331,7 @@ void show_browse_source(GtkButton *button, gpointer user_data) {
 	GtkFileChooserAction action = browse_files ? GTK_FILE_CHOOSER_ACTION_OPEN : GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER;
 	gchar *curr_path = (gchar*) gtk_entry_get_text((GtkEntry*) lookup_widget((GtkWidget*) button, "text_source"));
 	gchar *curr_folder = g_path_get_dirname(curr_path);
-		
+
 	dialog = gtk_file_chooser_dialog_new (_("Browse"), (GtkWindow*) main_window, action,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), curr_folder);
@@ -354,7 +358,7 @@ void show_browse_dest(GtkButton *button, gpointer user_data) {
 	GtkFileChooserAction action = browse_files ? GTK_FILE_CHOOSER_ACTION_OPEN : GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER;
 	gchar *curr_path = (gchar*) gtk_entry_get_text((GtkEntry*) lookup_widget((GtkWidget*) button, "text_dest"));
 	gchar *curr_folder = g_path_get_dirname(curr_path);
-		
+
 	dialog = gtk_file_chooser_dialog_new (_("Browse"), (GtkWindow*) main_window, action,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), curr_folder);
@@ -399,6 +403,7 @@ void on_play_clicked(GtkButton *button, gpointer user_data) {
 
 	if (get_checkbox(button, "check_sum")) argv[i++] = "-c";
 	if (get_checkbox(button, "check_symlink")) argv[i++] = "-l";
+	if (get_checkbox(button, "check_hardlink")) argv[i++] = "-H";
 	if (get_checkbox(button, "check_dev")) argv[i++] = "-D";
 	if (get_checkbox(button, "check_update")) argv[i++] = "--existing";
 	if (get_checkbox(button, "check_keepart")) argv[i++] = "--partial";
@@ -499,6 +504,7 @@ void on_main_create(GtkWindow *window, gpointer user_data) {
 		gtk_widget_destroy(error);
 	} else {
 //		g_spawn_command_line_sync("man rsync", &rsync_man, NULL, NULL, NULL);
+//		g_spawn_command_line_sync("sh -c 'info rsync | egrep -A9999 \"OPTIONS$\" | grep -B9999 \"DAEMON OPTIONS\"'", &rsync_man, NULL, NULL, NULL);
 		rsync_tips = gtk_tooltips_new();
 		set_tooltip(rsync_tips, "--times", "check_time");
 		set_tooltip(rsync_tips, "--perms", "check_perm");
@@ -514,7 +520,7 @@ void on_main_create(GtkWindow *window, gpointer user_data) {
 		set_tooltip(rsync_tips, "--modify-window=NUM", "check_windows");
 
 		set_tooltip(rsync_tips, "--checksum", "check_sum");
-		set_tooltip(rsync_tips, "--links", "check_symlink");
+		set_tooltip(rsync_tips, "--hard-links", "check_hardlink");
 		set_tooltip(rsync_tips, "-D", "check_dev");
 		set_tooltip(rsync_tips, "--existing", "check_update");
 		set_tooltip(rsync_tips, "--partial", "check_keepart");
@@ -610,7 +616,7 @@ void rsync_cleanup(gpointer data) {
 			scroll_to_end(view);
 			if (config_log) fputs(comm_after, log_file);
 			g_free(comm_after);
-		}	
+		}
 
 		gtk_button_set_label((GtkButton*) lookup_widget((GtkWidget*) data, "close"), "gtk-close");
 
@@ -640,8 +646,9 @@ void rsync_cleanup(gpointer data) {
 			g_free(error_list);
 		}
 		dryrunning = FALSE;
-		
-		if (cmdline_execute) on_close_clicked((GtkButton*) data, NULL);
+
+//		if (cmdline_execute) on_close_clicked((GtkButton*) data, NULL);
+		if (cmdline_execute && !(config_errorlist && had_error)) on_close_clicked((GtkButton*) data, NULL);
 	} else {
 		channel_closed = TRUE;
 	}
@@ -678,7 +685,7 @@ gboolean out_watch(GIOChannel *source, GIOCondition condition, gpointer data) {
 			if (strchr(str->str, '%') && str->str[0] == ' ') {
 				if (oldfile != NULL) file = g_strconcat(oldfile, NULL);
 				else file = g_strconcat(str->str, NULL);
-	
+
 				fraction = g_ascii_strtod(strchr(strchr(str->str, '%') - 4, ' '), NULL) / 100;
 				tmpp = (GtkProgressBar*)lookup_widget((GtkWidget*) data, "progress_file");
 				gtk_progress_bar_set_fraction(tmpp, fraction);
@@ -768,16 +775,18 @@ void on_rsync_show(GtkWidget *widget, gpointer user_data) {
 	GtkTextTag *tag;
 	GtkWidget *error;
 	gchar *comm_str, *comm_text, *comm_out, *comm_err, *comm_before, *tmpc;
+	gboolean halt = FALSE;
 
 	rsync_pid = 0;
 	had_error = FALSE;
 	gtk_label_set_ellipsize((GtkLabel*)lookup_widget(widget, "label_file"), PANGO_ELLIPSIZE_MIDDLE);
-	
+
 	if (get_checkbox((GtkWidget*) main_window, "check_com_before")) {
 		comm_str = (gchar*) gtk_entry_get_text((GtkEntry*) lookup_widget((GtkWidget*) main_window, "entry_com_before"));
 		if (!g_spawn_command_line_sync(comm_str, &comm_out, &comm_err, NULL, NULL)) {
 			comm_out = g_strconcat("", NULL);
 			comm_err = g_strconcat("Error launching command!\n", NULL);
+			if (get_checkbox((GtkWidget*) main_window, "check_com_halt")) halt = TRUE;
 		}
 		comm_before = g_strconcat(_("*** Launching BEFORE command:\n"), comm_str, "\n", comm_out, comm_err, "\n", NULL);
 		g_free(comm_out);
@@ -785,10 +794,13 @@ void on_rsync_show(GtkWidget *widget, gpointer user_data) {
 	} else {
 		comm_before = g_strconcat("", NULL);
 	}
-	
+
 	comm_str = g_strjoinv(" ", argv);
-	if (dryrunning) tmpc =_("*** Launching RSYNC command (simulation mode):\n");
-	else tmpc = _("*** Launching RSYNC command:\n");
+	if (halt) tmpc = "";
+	else {
+		if (dryrunning) tmpc =_("*** Launching RSYNC command (simulation mode):\n");
+		else tmpc = _("*** Launching RSYNC command:\n");
+	}
 	comm_text = g_strconcat(comm_before, tmpc, comm_str, "\n\n", NULL);
 	g_free(comm_before);
 	g_free(comm_str);
@@ -801,7 +813,7 @@ void on_rsync_show(GtkWidget *widget, gpointer user_data) {
 //	gtk_widget_get_size_request((GtkWidget*) lookup_widget(widget, "scrolled1"), &bogus, &height_expander);
 	g_get_current_time(&startime);
 
-	if (g_spawn_async_with_pipes(NULL, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, &rsync_pid, NULL, &out, &err, NULL)) {
+	if (!halt && g_spawn_async_with_pipes(NULL, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, &rsync_pid, NULL, &out, &err, NULL)) {
 		chout = g_io_channel_unix_new (out);
 		cherr = g_io_channel_unix_new (err);
 		g_io_channel_set_flags(chout, G_IO_FLAG_NONBLOCK, NULL);
@@ -816,10 +828,12 @@ void on_rsync_show(GtkWidget *widget, gpointer user_data) {
 	} else {
 		gtk_button_set_label((GtkButton*)lookup_widget(widget, "close"), "gtk-close");
 		gtk_widget_set_sensitive(lookup_widget(widget, "button_pause"), FALSE);
-		error = gtk_message_dialog_new((GtkWindow*) main_window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CANCEL,
-			_("Cannot execute rsync"));
-		gtk_dialog_run(GTK_DIALOG(error));
-		gtk_widget_destroy(error);
+		if (!halt) {
+			error = gtk_message_dialog_new((GtkWindow*) main_window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR,
+				GTK_BUTTONS_CANCEL, _("Cannot execute rsync"));
+			gtk_dialog_run(GTK_DIALOG(error));
+			gtk_widget_destroy(error);
+		}
 	}
 }
 
@@ -1017,7 +1031,7 @@ void on_rsync_info_activate(GtkMenuItem *menuitem, gpointer user_data) {
 void on_import1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	GtkWidget *dialog, *dialog2;
 	gint retval, i;
-		
+
 	dialog = gtk_file_chooser_dialog_new (_("Browse"), (GtkWindow*) main_window, GTK_FILE_CHOOSER_ACTION_OPEN,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
 	retval = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -1040,7 +1054,7 @@ void on_export1_activate (GtkMenuItem *menuitem, gpointer user_data) {
 	GtkWidget *dialog, *dialog2;
 	gchar *filename;
 	gint retval, i;
-		
+
 	i = gtk_combo_box_get_active((GtkComboBox*) lookup_widget((GtkWidget*) menuitem, "combo_session"));
 	dialog = gtk_file_chooser_dialog_new (_("Browse"), (GtkWindow*) main_window, GTK_FILE_CHOOSER_ACTION_SAVE,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT, NULL);
